@@ -1,4 +1,5 @@
 import random
+import sys
 import time
 
 from progress_table import ProgressTable
@@ -15,6 +16,7 @@ table = ProgressTable(
     custom_format=None,
     embedded_progress_bar=False,
     table_style="normal",
+    file=sys.stdout,
 )
 table.add_column("x", width=3)
 table.add_column("x root", color="red")
